@@ -113,8 +113,8 @@ public:
     Q_DECLARE_FLAGS(UpdateFlags, UpdateFlag)
 
 protected:
-    void resizeEvent(QResizeEvent* event) override;
-    
+    void resizeEvent(QResizeEvent *event) override;
+
 private:
     bool eventFilter(QObject *o, QEvent *e) override;
     bool event(QEvent *e) override;
@@ -135,7 +135,7 @@ private:
     void setPrecision();
     void setAngle();
     void setBase();
-    
+
     void setBaseFont(const QFont &font);
     const QFont &baseFont() const;
     bool isMinimumSize();
@@ -144,6 +144,7 @@ private:
     void setBitsetLayoutActive(bool active);
 
     void updateDisplay(UpdateFlags flags);
+    void insertNumericToInputDisplay(KCalcToken::TokenCode token);
     void insertFunctionToInputDisplay(KCalcToken::TokenCode token);
     void insertToInputDisplay(KCalcToken::TokenCode token);
     void insertToInputDisplay(const QString &token);
@@ -175,7 +176,7 @@ protected Q_SLOTS:
     void slotConstantsShow(bool toggled);
     void slotBitsetshow(bool toggled);
     void slotAngleSelected(QAbstractButton *button, bool checked);
-    void slotBaseSelected(QAbstractButton *button);
+    void slotBaseSelected();
     void slotNumberclicked(QAbstractButton *button);
     void slotEEclicked();
     void slotShifttoggled(bool myboolean);
@@ -222,6 +223,7 @@ protected Q_SLOTS:
     void slotConstclicked(int);
     void slotBackspaceclicked();
     void slotInputChanged();
+    void slotClearResult();
 
     void slotConstantToDisplay(const science_constant &const_chosen);
     void slotChooseScientificConst0(const science_constant &);
@@ -235,6 +237,7 @@ protected Q_SLOTS:
     void slotUpdateBitset(const KNumber &);
 
     void slotBaseModeAmountChanged(const KNumber &number);
+    void slotClearBaseModeAmount();
 
     void slotPaste();
 
@@ -250,6 +253,7 @@ private:
     void commit_Result_(bool toHistory = true);
     int load_Constants_(const QString &filePath);
 
+    bool numeral_system_mode_ = false;
     bool shift_mode_ = false;
     bool hyp_mode_ = false;
     bool update_history_window_ = false;
@@ -273,7 +277,6 @@ private:
     Constants *constants_ = nullptr; // this is the dialog for configuring const buttons
 
     QButtonGroup *angle_choose_group_ = nullptr;
-    QButtonGroup *base_choose_group_ = nullptr;
     // num_button_group_: 0-9 = digits, 0xA-0xF = hex-keys
     QButtonGroup *num_button_group_ = nullptr;
 
@@ -282,8 +285,6 @@ private:
     QList<QAbstractButton *> stat_buttons_;
     QList<QAbstractButton *> const_buttons_;
 
-    std::array<QLabel *, 4> base_conversion_labels_;
-
     KToggleAction *action_history_show_ = nullptr;
     KToggleAction *action_bitset_show_ = nullptr;
     KToggleAction *action_constants_show_ = nullptr;
@@ -306,4 +307,3 @@ private:
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KCalculator::UpdateFlags)
-
